==> nextcloud-31.0.8-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/text/l10n/fi.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Tiedosto lähetettiin",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Ladattu tiedosto on suurempi kuin php.ini-tiedostossa määritelty upload_max_filesize",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Ladattu tiedosto on suurempi kuin HTML-lomakkeessa määritelty MAX_FILE_SIZE",
    "The file was only partially uploaded" : "Tiedosto lähetettiin vain osittain",
    "No file was uploaded" : "Tiedostoa ei lähetetty",
    "Missing a temporary folder" : "Väliaikaiskansio puuttuu",
    "Could not write file to disk" : "Ei voitu kirjoittaa levylle",
    "A PHP extension stopped the file upload" : "PHP-laajennus pysäytti tiedoston lähetyksen",
    "No file uploaded or file size exceeds maximum of %s" : "Tiedostoa ei lähetetty tai sen koko ylitti maksimin %s",
    "Nextcloud Text" : "Nextcloud Text",
    "text document" : "Tekstiasiakirja",
    "New text file" : "Uusi tekstitiedosto",
    "Create new text file" : "Luo uusi tekstitiedosto",
    "Editing session has expired. Please reload the page." : "Muokkausistunto vanheni. Lataa sivu uudelleen.",
    "{user} has mentioned you in the text document {node}" : "{user} mainitsi sinut tekstiasiakirjassa {node}",
    "File not found" : "Tiedostoa ei löytynyt",
    "Readme" : "Lueminut",
    "Text" : "Teksti",
    "📝 Collaborative document editing" : "📝 Yhteistyöhön perustuvaa asiakirjojen muokkausta",
    "Insert result" : "Syötä tulos",
    "Nextcloud Assistant result copied" : "Nextcloud-avustajan tulos kopioitu",
    "Could not copy result to clipboard" : "Tulosta ei voitu kopioida leikepöydälle",
    "Nextcloud Assistant" : "Nextcloud-avustaja",
    "Translate" : "Käännä",
    "Show assistant results" : "Näytä avustajan tulokset",
    "Show result" : "Näytä tulos",
    "Delete task" : "Poista tehtävä",
    "Reload" : "Päivitä",
    "Reconnect" : "Yhdistä uudelleen",
    "This file is opened read-only as it is currently locked by {user}." : "Tämä tiedosto on avattu vain luku -tilassa, koska se on tällä hetkellä lukittu käyttäjän {user} toimesta.",
    "Enter your name so other people can see who is editing" : "Kirjoita nimesi, jotta muut näkevät kuka muokkaa asiakirjaa",
    "Edit guest name" : "Muokkaa vieraan nimeä",
    "Guest" : "Vieras",
    "Save guest name" : "Tallenna vieraan nimi",
    "Insert an attachment" : "Lisää liite",
    "Show link preview" : "Näytä linkin esikatselu",
    "Open in new tab" : "Avaa uudessa välilehdessä",
    "Remove link" : "Poista linkki",
    "Active people" : "Aktiiviset ihmiset",
    "guest" : "vieras",
    "Offline" : "Poissa",
    "Offline, changes will be saved when online" : "Ei yhteyttä. Muutokset tallennetaan, kun yhteys palautuu",
    "Saving …" : "Tallennetaan...",
    "Saved" : "Tallennettu",
    "Last saved {lastSave}" : "Viimeksi tallennettu {lastSave}",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Dokumenttia on muutettu editorin ulkopuolella. Muutoksia ei voida tallentaa.",
    "Unsaved changes" : "Tallentamattomia muutoksia",
    "Save document" : "Tallenna asiakirja",
    "Last saved" : "Viimeksi tallennettu",
    "Formatting and shortcuts" : "Muotoilu ja pikanäppäimet",
    "Speed up your writing with simple shortcuts." : "Nopeuta kirjoittamista pikanäppäimillä.",
    "Just type the Markdown syntax or use keyboard shortcuts from below." : "Kirjoita Markdown-syntaksia tai käytä alla olevia pikanäppäimiä.",
    "Just type the Markdown syntax from below." : "Kirjoita Markdown-syntaksia alapuolelta.",
    "Style" : "Tyyli",
    "Syntax" : "Syntaksi",
    "Keyboard shortcuts" : "Pikanäppäimet",
    "New paragraph" : "Uusi kappale",
    "Shift" : "Siirrä",
    "Bold" : "Lihavoitu",
    "Bold text" : "Lihavoitu teksti",
    "Italic" : "Kursivoitu",
    "Italicized text" : "Kursivoitu teksti",
    "Strikethrough" : "Yliviivattu",
    "Underline" : "Alleviivattu",
    "Underlined text" : "Alleviivattu teksti",
    "Heading 1" : "Otsikko 1",
    "Heading level 1" : "Otsikkotaso 1",
    "Heading 6" : "Otsikko 6",
    "Heading level 6" : "Otsikkotaso 6",
    "Unordered list" : "Lista",
    "An item" : "Tietue",
    "Ordered list" : "Numeroitu lista",
    "First item" : "Ensimmäinen tietue",
    "Checklist" : "Tarkistuslista",
    "Blockquote" : "Lohkolainaus",
    "Quoted text" : "Lainattu teksti",
    "Code block" : "Koodilohko",
    "Some code" : "Koodia",
    "Link" : "Linkki",
    "Insert emoji" : "Lisää emoji",
    "Mention someone" : "Mainitse käyttäjä",
    "name" : "nimi",
    "Action" : "Toiminto",
    "Undo" : "Kumoa",
    "Redo" : "Tee uudelleen",
    "Cannot copy, please copy the link manually" : "Kopioiminen ei onnistu. Kopioi linkki manuaalisesti",
    "Copy link to clipboard" : "Kopioi linkki leikepöydälle",
    "Open link" : "Avaa linkki",
    "Edit link" : "Muokkaa linkkiä",
    "Save changes" : "Tallenna muutokset",
    "Cancel" : "Peruuta",
    "URL" : "URL-osoite",
    "Upload from computer" : "Lähetä tietokoneelta",
    "Insert from Files" : "Syötä Tiedostot-sovelluksesta",
    "Formatting help" : "Muotoiluohje",
    "Link to file or folder" : "Linkki tiedostoon tai kansioon",
    "Link to website" : "Linkki verkkosivulle",
    "Update link" : "Päivitä linkki",
    "{menuItemName}, \"{selectedSubMenuItemName}\" is selected" : "{menuItemName}, \"{selectedSubMenuItemName}\" on valittu",
    "_%n word_::_%n words_" : ["%n sana","%n sanaa"],
    "_%n char_::_%n chars_" : ["%n merkki","%n merkkiä"],
    "Formatting menu bar" : "Muotoiluvalikko",
    "Translate from {language}" : "Käännä kielestä {language}",
    "Translate to {language}" : "Käännä kielelle {language}",
    "Translation failed" : "Kääntäminen epäonnistui",
    "To translate individual parts of the text, select it before using the translate function." : "Kääntääksesi yksittäisen osan tekstiä, valitse haluamasi tekstiosa ennen käännöstoiminnon käyttöä.",
    "Translate from" : "Lähdekieli",
    "Select language" : "Valitse kieli",
    "to" : "päättyen",
    "Translate to" : "Kohdekieli",
    "Replace" : "Korvaa",
    "Insert" : "Lisää",
    "No emoji found" : "Emojia ei löydy",
    "No command found" : "Komentoa ei löytynyt",
    "No user found" : "Käyttäjää ei löytynyt",
    "No suggestion found" : "Ehdotusta ei löytynyt",
    "Upload" : "Lähetä",
    "Edit" : "Muokkaa",
    "Copy code block" : "Kopioi koodilohko",
    "Copy code" : "Kopioi koodi",
    "Code block options" : "Koodilohkon asetukset",
    "Code block language" : "Koodilohkon kieli",
    "e.g. php, javascript, json…" : "esim. php, javascript, json…",
    "Source code" : "Lähdekoodi",
    "Diagram" : "Kaavio",
    "Both" : "Molemmat",
    "Mermaid documentation" : "Mermaid-dokumentaatio",
    "Failed to load" : "Lataaminen epäonnistui",
    "Delete this attachment" : "Poista tämä liite",
    "Delete this image" : "Poista tämä kuva",
    "Add row before" : "Lisää rivi ennen",
    "Add row after" : "Lisää rivi jälkeen",
    "Delete this row" : "Poista tämä rivi",
    "Add column before" : "Lisää sarake ennen",
    "Add column after" : "Lisää sarake jälkeen",
    "Delete this column" : "Poista tämä sarake",
    "Delete this table" : "Poista tämä taulu",
    "Show folder description" : "Näytä kansion kuvaus",
    "Done" : "Valmis",
    "Headings" : "Otsikot",
    "Heading 2" : "Otsikko 2",
    "Heading 3" : "Otsikko 3",
    "Heading 4" : "Otsikko 4",
    "Heading 5" : "Otsikko 5",
    "Lists" : "Luettelot",
    "To-Do list" : "Tehtävälista",
    "Table" : "Taulukko",
    "Details" : "Tiedot",
    "Insert link" : "Lisää linkki",
    "Insert attachment" : "Lisää liite",
    "Command" : "Komento",
    "Formatting" : "Muotoilu",
    "Select file or folder to link to" : "Valitse tiedosto tai kansio, johon linkitetään",
    "Choose" : "Valitse",
    "Choose {file}" : "Valitse {file}",
    "Add folder description" : "Lisään kansion kuvaus",
    "\"{name}\" already exist!" : "\"{name}\" on jo olemassa!",
    "Created \"{name}\"" : "Luotu \"{name}\"",
    "Copied to the clipboard" : "Kopioitu leikepöydälle",
    "Could not copy to the clipboard" : "Ei voitu kopioida leikepöydälle",
    "Link to this section" : "Linkki tähän osioon",
    "Use current version" : "Käytä nykyistä versiota",
    "Use the saved version" : "Käytä tallennettua versiota",
    "Document idle for {timeout} minutes, click to continue editing" : "Dokumentti on ollut käyttämättömänä {timeout} minuuttia, klikkaa jatkaaksesi muokkausta",
    "Detect language" : "Havaitse kieli",
    "Info" : "Tietoa",
    "Success" : "Onnistui",
    "Warning" : "Varoitus"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/text/l10n/fi.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Tiedosto lähetettiin",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Ladattu tiedosto on suurempi kuin php.ini-tiedostossa määritelty upload_max_filesize",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Ladattu tiedosto on suurempi kuin HTML-lomakkeessa määritelty MAX_FILE_SIZE",
    "The file was only partially uploaded" : "Tiedosto lähetettiin vain osittain",
    "No file was uploaded" : "Tiedostoa ei lähetetty",
    "Missing a temporary folder" : "Väliaikaiskansio puuttuu",
    "Could not write file to disk" : "Ei voitu kirjoittaa levylle",
    "A PHP extension stopped the file upload" : "PHP-laajennus pysäytti tiedoston lähetyksen",
    "No file uploaded or file size exceeds maximum of %s" : "Tiedostoa ei lähetetty tai sen koko ylitti maksimin %s",
    "Nextcloud Text" : "Nextcloud Text",
    "text document" : "Tekstiasiakirja",
    "New text file" : "Uusi tekstitiedosto",
    "Create new text file" : "Luo uusi tekstitiedosto",
    "Editing session has expired. Please reload the page." : "Muokkausistunto vanheni. Lataa sivu uudelleen.",
    "{user} has mentioned you in the text document {node}" : "{user} mainitsi sinut tekstiasiakirjassa {node}",
    "File not found" : "Tiedostoa ei löytynyt",
    "Readme" : "Lueminut",
    "Text" : "Teksti",
    "📝 Collaborative document editing" : "📝 Yhteistyöhön perustuvaa asiakirjojen muokkausta",
    "Reload" : "Päivitä",
    "Reconnect" : "Yhdistä uudelleen",
    "This file is opened read-only as it is currently locked by {user}." : "Tämä tiedosto on avattu vain luku -tilassa, koska se on tällä hetkellä lukittu käyttäjän {user} toimesta.",
    "Enter your name so other people can see who is editing" : "Kirjoita nimesi, jotta muut näkevät kuka muokkaa asiakirjaa",
    "Enter your name" : "Kirjoita nimesi",
    "Guest" : "Vieras",
    "you" : "sinä",
    "edit" : "muokkaa",
    "Insert an attachment" : "Lisää liite",
    "Show link preview" : "Näytä linkin esikatselu",
    "Open in new tab" : "Avaa uudessa välilehdessä",
    "Copy link" : "Kopioi linkki",
    "Remove link" : "Poista linkki",
    "Active people" : "Aktiiviset ihmiset",
    "guest" : "vieras",
    "Offline" : "Poissa",
    "Offline, changes will be saved when online" : "Ei yhteyttä. Muutokset tallennetaan, kun yhteys palautuu",
    "Saving …" : "Tallennetaan...",
    "Saved" : "Tallennettu",
    "Last saved {lastSave}" : "Viimeksi tallennettu {lastSave}",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Dokumenttia on muutettu editorin ulkopuolella. Muutoksia ei voida tallentaa.",
    "Unsaved changes" : "Tallentamattomia muutoksia",
    "Save document" : "Tallenna asiakirja",
    "Last saved" : "Viimeksi tallennettu",
    "Formatting and shortcuts" : "Muotoilu ja pikanäppäimet",
    "Speed up your writing with simple shortcuts." : "Nopeuta kirjoittamista pikanäppäimillä.",
    "Just type the Markdown syntax or use keyboard shortcuts from below." : "Kirjoita Markdown-syntaksia tai käytä alla olevia pikanäppäimiä.",
    "Just type the Markdown syntax from below." : "Kirjoita Markdown-syntaksia alapuolelta.",
    "Style" : "Tyyli",
    "Syntax" : "Syntaksi",
    "Keyboard shortcuts" : "Pikanäppäimet",
    "New paragraph" : "Uusi kappale",
    "Shift" : "Siirrä",
    "Bold" : "Lihavoitu",
    "Bold text" : "Lihavoitu teksti",
    "Italic" : "Kursivoitu",
    "Italicized text" : "Kursivoitu teksti",
    "Strikethrough" : "Yliviivattu",
    "Underline" : "Alleviivattu",
    "Underlined text" : "Alleviivattu teksti",
    "Heading 1" : "Otsikko 1",
    "Heading level 1" : "Otsikkotaso 1",
    "Heading 6" : "Otsikko 6",
    "Heading level 6" : "Otsikkotaso 6",
    "Unordered list" : "Lista",
    "An item" : "Tietue",
    "Ordered list" : "Numeroitu lista",
    "First item" : "Ensimmäinen tietue",
    "Checklist" : "Tarkistuslista",
    "Blockquote" : "Lohkolainaus",
    "Quoted text" : "Lainattu teksti",
    "Code block" : "Koodilohko",
    "Some code" : "Koodia",
    "Link" : "Linkki",
    "Insert emoji" : "Lisää emoji",
    "Mention someone" : "Mainitse käyttäjä",
    "name" : "nimi",
    "Action" : "Toiminto",
    "Undo" : "Kumoa",
    "Redo" : "Tee uudelleen",
    "Open link" : "Avaa linkki",
    "Edit link" : "Muokkaa linkkiä",
    "Save changes" : "Tallenna muutokset",
    "Cancel" : "Peruuta",
    "URL" : "URL-osoite",
    "Save" : "Tallenna",
    "Upload from computer" : "Lähetä tietokoneelta",
    "Insert from Files" : "Syötä Tiedostot-sovelluksesta",
    "Formatting help" : "Muotoiluohje",
    "Link to file or folder" : "Linkki tiedostoon tai kansioon",
    "Link to website" : "Linkki verkkosivulle",
    "Update link" : "Päivitä linkki",
    "{menuItemName}, \"{selectedSubMenuItemName}\" is selected" : "{menuItemName}, \"{selectedSubMenuItemName}\" on valittu",
    "Insert result" : "Syötä tulos",
    "Nextcloud Assistant result copied" : "Nextcloud-avustajan tulos kopioitu",
    "Could not copy result to clipboard" : "Tulosta ei voitu kopioida leikepöydälle",
    "Translate" : "Käännä",
    "Show assistant results" : "Näytä avustajan tulokset",
    "Nextcloud Assistant" : "Nextcloud-avustaja",
    "Show result" : "Näytä tulos",
    "Delete task" : "Poista tehtävä",
    "_%n word_::_%n words_" : ["%n sana","%n sanaa"],
    "_%n char_::_%n chars_" : ["%n merkki","%n merkkiä"],
    "Formatting menu bar" : "Muotoiluvalikko",
    "Translate from {language}" : "Käännä kielestä {language}",
    "Translate to {language}" : "Käännä kielelle {language}",
    "Translation failed" : "Kääntäminen epäonnistui",
    "To translate individual parts of the text, select it before using the translate function." : "Kääntääksesi yksittäisen osan tekstiä, valitse haluamasi tekstiosa ennen käännöstoiminnon käyttöä.",
    "Translate from" : "Lähdekieli",
    "Select language" : "Valitse kieli",
    "to" : "päättyen",
    "Translate to" : "Kohdekieli",
    "Replace" : "Korvaa",
    "Insert" : "Lisää",
    "No emoji found" : "Emojia ei löydy",
    "No command found" : "Komentoa ei löytynyt",
    "No user found" : "Käyttäjää ei löytynyt",
    "No suggestion found" : "Ehdotusta ei löytynyt",
    "Upload" : "Lähetä",
    "Edit" : "Muokkaa",
    "Copy code block" : "Kopioi koodilohko",
    "Copy code" : "Kopioi koodi",
    "Code block options" : "Koodilohkon asetukset",
    "Code block language" : "Koodilohkon kieli",
    "e.g. php, javascript, json…" : "esim. php, javascript, json…",
    "Source code" : "Lähdekoodi",
    "Diagram" : "Kaavio",
    "Both" : "Molemmat",
    "Mermaid documentation" : "Mermaid-dokumentaatio",
    "Failed to load" : "Lataaminen epäonnistui",
    "Delete this attachment" : "Poista tämä liite",
    "Delete this image" : "Poista tämä kuva",
    "Add row before" : "Lisää rivi ennen",
    "Add row after" : "Lisää rivi jälkeen",
    "Delete this row" : "Poista tämä rivi",
    "Add column before" : "Lisää sarake ennen",
    "Add column after" : "Lisää sarake jälkeen",
    "Delete this column" : "Poista tämä sarake",
    "Delete this table" : "Poista tämä taulu",
    "Show folder description" : "Näytä kansion kuvaus",
    "Done" : "Valmis",
    "Headings" : "Otsikot",
    "Heading 2" : "Otsikko 2",
    "Heading 3" : "Otsikko 3",
    "Heading 4" : "Otsikko 4",
    "Heading 5" : "Otsikko 5",
    "Lists" : "Luettelot",
    "To-Do list" : "Tehtävälista",
    "Table" : "Taulukko",
    "Details" : "Tiedot",
    "Insert link" : "Lisää linkki",
    "Insert attachment" : "Lisää liite",
    "Command" : "Komento",
    "Formatting" : "Muotoilu",
    "Select file or folder to link to" : "Valitse tiedosto tai kansio, johon linkitetään",
    "Choose" : "Valitse",
    "Choose {file}" : "Valitse {file}",
    "Add folder description" : "Lisään kansion kuvaus",
    "\"{name}\" already exist!" : "\"{name}\" on jo olemassa!",
    "Created \"{name}\"" : "Luotu \"{name}\"",
    "Copied to the clipboard" : "Kopioitu leikepöydälle",
    "Could not copy to the clipboard" : "Ei voitu kopioida leikepöydälle",
    "Link to this section" : "Linkki tähän osioon",
    "Edit guest name" : "Muokkaa vieraan nimeä",
    "Save guest name" : "Tallenna vieraan nimi",
    "Cannot copy, please copy the link manually" : "Kopioiminen ei onnistu. Kopioi linkki manuaalisesti",
    "Copy link to clipboard" : "Kopioi linkki leikepöydälle"
},
"nplurals=2; plural=(n != 1);");
